@@ -48,7 +48,7 @@ from command import BzrToolsCommand
 
 class cmd_graph_ancestry(BzrToolsCommand):
     """Produce ancestry graphs using dot.
-    
+
     Output format is detected according to file extension.  Some of the more
     common output formats are html, png, gif, svg, ps.  An extension of '.dot'
     will cause a dot graph file to be produced.  HTML output has mouseovers
@@ -342,9 +342,17 @@ class cmd_shell(BzrToolsCommand):
     --all        --help       --revision   --show-ids
     bzr bzrtools:287/> status --
     """
-    def run(self):
+    takes_options = [
+        Option('directory',
+            help='Branch in which to start the shell, '
+                 'rather than the one containing the working directory.',
+            short_name='d',
+            type=unicode,
+            ),
+        ]
+    def run(self, directory=None):
         import shell
-        return shell.run_shell()
+        return shell.run_shell(directory)
 
 
 class cmd_branch_history(BzrToolsCommand):
@@ -523,18 +531,18 @@ class cmd_conflict_diff(BzrToolsCommand):
     """Compare a conflicted file against BASE."""
 
     encoding_type = 'exact'
-    takes_args = ['file']
+    takes_args = ['file*']
     takes_options = [
         RegistryOption.from_kwargs('direction', 'Direction of comparison.',
             value_switches=True, enum_switch=False,
             other='Compare OTHER against common base.',
             this='Compare THIS against common base.')]
 
-    def run(self, file, direction='other'):
+    def run(self, file_list, direction='other'):
         from bzrlib.plugins.bzrtools.colordiff import DiffWriter
-        from conflict_diff import conflict_diff
+        from conflict_diff import ConflictDiffer
         dw = DiffWriter(self.outf, check_style=False, color='auto')
-        conflict_diff(dw, file, direction)
+        ConflictDiffer().run(dw, file_list, direction)
 
 
 class cmd_rspush(BzrToolsCommand):
