@@ -20,7 +20,7 @@ import time
 
 from bzrlib.branch import Branch
 from bzrlib.errors import BzrCommandError, NoSuchRevision
-from bzrlib.graph import node_distances, select_farthest
+from bzrlib.deprecated_graph import node_distances, select_farthest
 from bzrlib.revision import NULL_REVISION
 
 from bzrtools import short_committer
