@@ -4,7 +4,7 @@ import re
 from subprocess import call, PIPE
 import sys
 
-sys.path.insert(0, '..')
+sys.path.insert(0, '/home/abentley/bzrplugins')
 sys.path.insert(0, os.path.dirname(os.path.realpath('/home/abentley/bin/bzr')))
 import bzrtools
 print "bzrtools version: %s" % bzrtools.__version__
@@ -21,7 +21,7 @@ if newsmatch is None:
     sys.exit(1)
 else:
     print "NEWS entry found"
-final_name = '../bzrtools-%s.tar.gz' % bzrtools.__version__
+final_name = '../bzrtools-release/bzrtools-%s.tar.gz' % bzrtools.__version__
 if os.path.exists('../bzrtools.tar.gz'):
     print "Temp file exists already."
     sys.exit(1)
