@@ -26,6 +26,11 @@ class TestBzrTools(TestCaseWithTransport):
         self.run_bzr('init')
         self.run_bzr('fetch-ghosts .')
 
+    def test_fetch_ghosts_with_saved(self):
+        wt = self.make_branch_and_tree('.')
+        wt.branch.set_parent('.')
+        self.run_bzr('fetch-ghosts')
+
     def test_patch(self):
         self.run_bzr('init')
         file('myfile', 'wb').write('hello')
