@@ -13,7 +13,7 @@ from bzrlib.plugins.bzrtools.upstream_import import (
     import_tar,
     import_zip,
     import_dir,
-    top_directory,
+    top_path,
     ZipFileWrapper,
 )
 from bzrlib.tests import TestCaseInTempDir
@@ -154,14 +154,15 @@ class TestImport(TestCaseInTempDir):
             return ZipFileWrapper(fileobj, 'w')
         return self.make_archive(maker)
 
-    def test_top_directory(self):
-        self.assertEqual(top_directory('ab/b/c'), 'ab')
-        self.assertEqual(top_directory('/etc'), '/')
+    def test_top_path(self):
+        self.assertEqual(top_path('ab/b/c'), 'ab')
+        self.assertEqual(top_path('etc'), 'etc')
+        self.assertEqual(top_path('project-0.1'), 'project-0.1')
 
     def test_common_directory(self):
         self.assertEqual(common_directory(['ab/c/d', 'ab/c/e']), 'ab')
         self.assertIs(common_directory(['ab/c/d', 'ac/c/e']), None)
-        self.assertIs(None, common_directory(['FEEDME']))
+        self.assertEqual('FEEDME', common_directory(['FEEDME']))
 
     def test_untar(self):
         def builder(fileobj, mode='w'):
