@@ -12,7 +12,7 @@ from bzrlib import generate_ids
 from bzrlib.bzrdir import BzrDir
 from bzrlib.errors import NoSuchFile, BzrCommandError, NotBranchError
 from bzrlib.osutils import (pathjoin, isdir, file_iterator, basename,
-                            file_kind)
+                            file_kind, splitpath)
 from bzrlib.trace import warning
 from bzrlib.transform import TreeTransform, resolve_conflicts, cook_conflicts
 from bzrlib.workingtree import WorkingTree
@@ -117,22 +117,20 @@ class FileInfo(object):
             return False
 
 
-def top_directory(path):
+def top_path(path):
     """Return the top directory given in a path."""
-    dirname = os.path.dirname(path)
-    last_dirname = dirname
-    while True:
-        dirname = os.path.dirname(dirname)
-        if dirname == '' or dirname == last_dirname:
-            return last_dirname
-        last_dirname = dirname
+    components = splitpath(path)
+    if len(components) > 0:
+        return components[0]
+    else:
+        return ''
 
 
 def common_directory(names):
     """Determine a single directory prefix from a list of names"""
     possible_prefix = None
     for name in names:
-        name_top = top_directory(name)
+        name_top = top_path(name)
         if name_top == '':
             return None
         if possible_prefix is None:
